pub struct ImportsIndices {}Expand description
Auto-generated bindings for index of the exports of
imports.
This is an implementation detail of ImportsPre and can
be constructed if needed as well.
For more information see Imports as well.
Implementations
Sourceimpl ImportsIndices
impl ImportsIndices
Sourcepub fn new(component: &Component) -> Result<Self>
pub fn new(component: &Component) -> Result<Self>
Creates a new copy of ImportsIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn new_instance(
store: impl AsContextMut,
instance: &Instance,
) -> Result<Self>
pub fn new_instance( store: impl AsContextMut, instance: &Instance, ) -> Result<Self>
Creates a new instance of ImportsIndices from an
instantiated component.
This method of creating a Imports will perform string
lookups for all exports when this method is called. This
will only succeed if the provided instance matches the
requirements of Imports.